use strict;
use warnings;

package Task::BeLike::FLORA;
BEGIN {
  $Task::BeLike::FLORA::AUTHORITY = 'cpan:FLORA';
}
BEGIN {
  $Task::BeLike::FLORA::VERSION = '0.02';
}
# ABSTRACT: Modules FLORA uses


1;

__END__
=pod

=head1 NAME

Task::BeLike::FLORA - Modules FLORA uses

=head1 VERSION

version 0.02

=head1 TASK CONTENTS

=head2 Applications

=head3 App::Ack

=head3 App::Metabase::Relayd

=head3 App::Nopaste

=head3 App::Software::License

=head3 App::cpanminus

=head3 App::cpanoutdated

=head3 CPAN::Mini

=head3 CPAN::Mini::Devel

=head3 CPAN::Uploader

=head2 Optional Dependencies Of Other Modules

=head3 CPAN::Reporter

=head3 PadWalker

=head3 Test::Reporter

=head3 Test::Reporter::Transport::Socket

=head2 Development Tools

=head3 Carp::Always

=head3 Carp::Always::Color

=head3 Carp::REPL

=head3 Devel::Cover

=head3 Devel::NYTProf

=head3 Dist::Zilla

=head3 Dist::Zilla::PluginBundle::FLORA

=head3 Gitalist

=head3 Module::Install 0.95

=head3 Module::Install::AuthorRequires

=head3 Module::Install::AuthorTests

=head3 Module::Install::CheckConflicts

=head3 Module::Install::ExtraTests

=head3 Perl::Tidy

=head3 Pod::Coverage::TrustPod

=head3 Test::Pod

=head3 Test::Pod::Coverage

=head3 V

=head2 Modules I use a lot

=head3 Catalyst::Model::KiokuDB

=head3 Data::Visitor

=head3 Email::MIME::Kit

=head3 Email::MIME::Kit::Assembler::Markdown

=head3 Email::MIME::Kit::Renderer::TT

=head3 Email::Sender

=head3 Function::Parameters

=head3 JSON

=head3 List::AllUtils

=head3 Method::Signatures::Simple

=head3 Moose

=head3 Moose::Autobox

=head3 MooseX::Declare

=head3 MooseX::LazyRequire

=head3 MooseX::Types::Common

=head3 MooseX::Types::DateTime

=head3 MooseX::Types::Email

=head3 MooseX::Types::LoadableClass

=head3 MooseX::Types::Path::Class

=head3 MooseX::Types::URI

=head3 Task::Catalyst

=head3 Task::KiokuDB

=head3 Task::Plack

=head3 Test::WWW::Mechanize::Catalyst

=head1 AUTHOR

  Florian Ragwitz <rafl@debian.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Florian Ragwitz.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

